Class: GroupDocsConversionCloud::ImageConvertOptions
- Inherits:
-
Object
- Object
- GroupDocsConversionCloud::ImageConvertOptions
- Defined in:
- lib/groupdocs_conversion_cloud/models/image_convert_options.rb
Overview
Options for to Image conversion
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#background_color ⇒ Object
Gets or sets a background color.
-
#brightness ⇒ Object
Adjust image brightness.
-
#contrast ⇒ Object
Adjust image contrast.
-
#flip_mode ⇒ Object
Image flip mode.
-
#from_page ⇒ Object
Start conversion from FromPage page.
-
#gamma ⇒ Object
Adjust image gamma.
-
#grayscale ⇒ Object
Convert to grayscale image.
-
#height ⇒ Object
Desired image height after conversion.
-
#horizontal_resolution ⇒ Object
Desired image horizontal resolution after conversion.
-
#jpeg_options ⇒ Object
Options for converting to Jpeg-compatible image.
-
#pages ⇒ Object
Convert specific pages.
-
#pages_count ⇒ Object
Number of pages to convert.
-
#psd_options ⇒ Object
Options for converting to PSD-compatible image.
-
#rotate_angle ⇒ Object
Image rotation angle.
-
#tiff_options ⇒ Object
Options for converting to Tiff-compatible image.
-
#use_pdf ⇒ Object
If true, the input firstly is converted to PDF and after that to desired format.
-
#vertical_resolution ⇒ Object
Desired image vertical resolution after conversion.
-
#watermark_options ⇒ Object
Watermark specific options.
-
#webp_options ⇒ Object
Options for converting to WebP-compatible image.
-
#width ⇒ Object
Desired image width after conversion.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(other) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(other) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImageConvertOptions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#uncap(str) ⇒ Object
Downcases first letter.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ImageConvertOptions
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 169 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.key?(:'FromPage') self.from_page = attributes[:'FromPage'] end if attributes.key?(:'PagesCount') self.pages_count = attributes[:'PagesCount'] end if attributes.key?(:'Pages') if (value = attributes[:'Pages']).is_a?(Array) self.pages = value end end if attributes.key?(:'WatermarkOptions') self. = attributes[:'WatermarkOptions'] end if attributes.key?(:'Width') self.width = attributes[:'Width'] end if attributes.key?(:'Height') self.height = attributes[:'Height'] end if attributes.key?(:'HorizontalResolution') self.horizontal_resolution = attributes[:'HorizontalResolution'] end if attributes.key?(:'VerticalResolution') self.vertical_resolution = attributes[:'VerticalResolution'] end if attributes.key?(:'Grayscale') self.grayscale = attributes[:'Grayscale'] end if attributes.key?(:'RotateAngle') self.rotate_angle = attributes[:'RotateAngle'] end if attributes.key?(:'UsePdf') self.use_pdf = attributes[:'UsePdf'] end if attributes.key?(:'Brightness') self.brightness = attributes[:'Brightness'] end if attributes.key?(:'Contrast') self.contrast = attributes[:'Contrast'] end if attributes.key?(:'Gamma') self.gamma = attributes[:'Gamma'] end if attributes.key?(:'FlipMode') self.flip_mode = attributes[:'FlipMode'] end if attributes.key?(:'BackgroundColor') self.background_color = attributes[:'BackgroundColor'] end if attributes.key?(:'JpegOptions') self. = attributes[:'JpegOptions'] end if attributes.key?(:'PsdOptions') self. = attributes[:'PsdOptions'] end if attributes.key?(:'TiffOptions') self. = attributes[:'TiffOptions'] end if attributes.key?(:'WebpOptions') self. = attributes[:'WebpOptions'] end end |
Instance Attribute Details
#background_color ⇒ Object
Gets or sets a background color.
80 81 82 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 80 def background_color @background_color end |
#brightness ⇒ Object
Adjust image brightness
68 69 70 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 68 def brightness @brightness end |
#contrast ⇒ Object
Adjust image contrast
71 72 73 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 71 def contrast @contrast end |
#flip_mode ⇒ Object
Image flip mode
77 78 79 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 77 def flip_mode @flip_mode end |
#from_page ⇒ Object
Start conversion from FromPage page
35 36 37 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 35 def from_page @from_page end |
#gamma ⇒ Object
Adjust image gamma
74 75 76 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 74 def gamma @gamma end |
#grayscale ⇒ Object
Convert to grayscale image
59 60 61 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 59 def grayscale @grayscale end |
#height ⇒ Object
Desired image height after conversion
50 51 52 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 50 def height @height end |
#horizontal_resolution ⇒ Object
Desired image horizontal resolution after conversion. The default resolution is the resolution of the input file or 96dpi
53 54 55 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 53 def horizontal_resolution @horizontal_resolution end |
#jpeg_options ⇒ Object
Options for converting to Jpeg-compatible image
83 84 85 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 83 def @jpeg_options end |
#pages ⇒ Object
Convert specific pages. The list contains the page indexes of the pages to be converted
41 42 43 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 41 def pages @pages end |
#pages_count ⇒ Object
Number of pages to convert
38 39 40 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 38 def pages_count @pages_count end |
#psd_options ⇒ Object
Options for converting to PSD-compatible image
86 87 88 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 86 def @psd_options end |
#rotate_angle ⇒ Object
Image rotation angle
62 63 64 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 62 def rotate_angle @rotate_angle end |
#tiff_options ⇒ Object
Options for converting to Tiff-compatible image
89 90 91 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 89 def @tiff_options end |
#use_pdf ⇒ Object
If true, the input firstly is converted to PDF and after that to desired format
65 66 67 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 65 def use_pdf @use_pdf end |
#vertical_resolution ⇒ Object
Desired image vertical resolution after conversion. The default resolution is the resolution of the input file or 96dpi
56 57 58 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 56 def vertical_resolution @vertical_resolution end |
#watermark_options ⇒ Object
Watermark specific options
44 45 46 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 44 def @watermark_options end |
#webp_options ⇒ Object
Options for converting to WebP-compatible image
92 93 94 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 92 def @webp_options end |
#width ⇒ Object
Desired image width after conversion
47 48 49 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 47 def width @width end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 116 def self.attribute_map { :'from_page' => :'FromPage', :'pages_count' => :'PagesCount', :'pages' => :'Pages', :'watermark_options' => :'WatermarkOptions', :'width' => :'Width', :'height' => :'Height', :'horizontal_resolution' => :'HorizontalResolution', :'vertical_resolution' => :'VerticalResolution', :'grayscale' => :'Grayscale', :'rotate_angle' => :'RotateAngle', :'use_pdf' => :'UsePdf', :'brightness' => :'Brightness', :'contrast' => :'Contrast', :'gamma' => :'Gamma', :'flip_mode' => :'FlipMode', :'background_color' => :'BackgroundColor', :'jpeg_options' => :'JpegOptions', :'psd_options' => :'PsdOptions', :'tiff_options' => :'TiffOptions', :'webp_options' => :'WebpOptions' } end |
.swagger_types ⇒ Object
Attribute type mapping.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 142 def self.swagger_types { :'from_page' => :'Integer', :'pages_count' => :'Integer', :'pages' => :'Array<Integer>', :'watermark_options' => :'WatermarkOptions', :'width' => :'Integer', :'height' => :'Integer', :'horizontal_resolution' => :'Integer', :'vertical_resolution' => :'Integer', :'grayscale' => :'BOOLEAN', :'rotate_angle' => :'Integer', :'use_pdf' => :'BOOLEAN', :'brightness' => :'Integer', :'contrast' => :'Integer', :'gamma' => :'Float', :'flip_mode' => :'String', :'background_color' => :'String', :'jpeg_options' => :'JpgConvertOptions', :'psd_options' => :'PsdConvertOptions', :'tiff_options' => :'TiffConvertOptions', :'webp_options' => :'WebpConvertOptions' } end |
Instance Method Details
#==(other) ⇒ Object
Checks equality by comparing each attribute.
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 355 def ==(other) return true if self.equal?(other) self.class == other.class && from_page == other.from_page && pages_count == other.pages_count && pages == other.pages && == other. && width == other.width && height == other.height && horizontal_resolution == other.horizontal_resolution && vertical_resolution == other.vertical_resolution && grayscale == other.grayscale && rotate_angle == other.rotate_angle && use_pdf == other.use_pdf && brightness == other.brightness && contrast == other.contrast && gamma == other.gamma && flip_mode == other.flip_mode && background_color == other.background_color && == other. && == other. && == other. && == other. end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 425 def _deserialize(type, value) case type.to_sym when :DateTime Date.parse value when :Date Date.parse value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = GroupDocsConversionCloud.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 492 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 401 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| pname = uncap(self.class.attribute_map[key]).intern value = attributes[pname] if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the the attribute # is documented as an array but the input is not if value.is_a?(Array) self.send("#{key}=", value.map { |v| _deserialize($1, v) }) end elsif !value.nil? self.send("#{key}=", _deserialize(type, value)) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(other) ⇒ Boolean
382 383 384 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 382 def eql?(other) self == other end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
388 389 390 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 388 def hash [from_page, pages_count, pages, , width, height, horizontal_resolution, vertical_resolution, grayscale, rotate_angle, use_pdf, brightness, contrast, gamma, flip_mode, background_color, , , , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 261 def list_invalid_properties invalid_properties = [] if @from_page.nil? invalid_properties.push("invalid value for 'from_page', from_page cannot be nil.") end if @pages_count.nil? invalid_properties.push("invalid value for 'pages_count', pages_count cannot be nil.") end if @width.nil? invalid_properties.push("invalid value for 'width', width cannot be nil.") end if @height.nil? invalid_properties.push("invalid value for 'height', height cannot be nil.") end if @horizontal_resolution.nil? invalid_properties.push("invalid value for 'horizontal_resolution', horizontal_resolution cannot be nil.") end if @vertical_resolution.nil? invalid_properties.push("invalid value for 'vertical_resolution', vertical_resolution cannot be nil.") end if @grayscale.nil? invalid_properties.push("invalid value for 'grayscale', grayscale cannot be nil.") end if @rotate_angle.nil? invalid_properties.push("invalid value for 'rotate_angle', rotate_angle cannot be nil.") end if @use_pdf.nil? invalid_properties.push("invalid value for 'use_pdf', use_pdf cannot be nil.") end if @brightness.nil? invalid_properties.push("invalid value for 'brightness', brightness cannot be nil.") end if @contrast.nil? invalid_properties.push("invalid value for 'contrast', contrast cannot be nil.") end if @gamma.nil? invalid_properties.push("invalid value for 'gamma', gamma cannot be nil.") end if @flip_mode.nil? invalid_properties.push("invalid value for 'flip_mode', flip_mode cannot be nil.") end return invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
472 473 474 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 472 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
478 479 480 481 482 483 484 485 486 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 478 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
466 467 468 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 466 def to_s to_hash.to_s end |
#uncap(str) ⇒ Object
Downcases first letter.
394 395 396 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 394 def uncap(str) str[0, 1].downcase + str[1..-1] end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/groupdocs_conversion_cloud/models/image_convert_options.rb', line 320 def valid? return false if @from_page.nil? return false if @pages_count.nil? return false if @width.nil? return false if @height.nil? return false if @horizontal_resolution.nil? return false if @vertical_resolution.nil? return false if @grayscale.nil? return false if @rotate_angle.nil? return false if @use_pdf.nil? return false if @brightness.nil? return false if @contrast.nil? return false if @gamma.nil? return false if @flip_mode.nil? flip_mode_validator = EnumAttributeValidator.new('String', ["None", "FlipX", "FlipY", "FlipXY"]) return false unless flip_mode_validator.valid?(@flip_mode) return true end |